#
# spec file for package kdevelop-plugin-python3
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname kdev-python
%define mypython python3
%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kdevelop-plugin-python3
Version:        25.04.1
Release:        1.0.2.1.sr20250601
Summary:        Python support for KDevelop
License:        GPL-2.0-or-later
URL:            https://www.kdevelop.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
# PATCH-FIX-OPENSUSE
Patch0:         fix-for-python3.6.patch
BuildRequires:  %{mypython} >= 3.4.3
BuildRequires:  %{mypython}-devel >= 3.4.3
BuildRequires:  fdupes
BuildRequires:  kdevelop >= 6.0
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KDevPlatform)
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6TextEditor) >= %{kf6_version}
BuildRequires:  cmake(KF6ThreadWeaver) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
# Package was renamed before 24.08 release
Requires:       kdevelop >= 24.08.0
Recommends:     %{mypython}-pep8
Provides:       kdevelop4-plugin-python = %{version}
Obsoletes:      kdevelop4-plugin-python < %{version}
Obsoletes:      kdevelop5-plugin-python3 < %{version}
# Only build on archs where Qt6WebEngine is available
ExclusiveArch:  aarch64 x86_64 %{x86_64} riscv64

%description
A KDevelop plugin which provides Python language support, including code
completion and debugging using PDB.

%package lang
Summary:        Translations for package %{name}
Requires:       %{name} = %{version}
Supplements:    (bundle-lang-other and %{name})
Conflicts:      kdevelop4-plugin-python-lang
Obsoletes:      kdevelop5-plugin-python3-lang < %{version}
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

# Remove obsolete docs
rm -r %{buildroot}%{_kf6_sharedir}/kdevpythonsupport/documentation_files/{PyKDE4,PyQt4}

%find_lang kdevpython %{name}.lang

%fdupes %{buildroot}

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc README
%{_kf6_appstreamdir}/org.kde.kdev-python.metainfo.xml
%{_kf6_debugdir}/kdevpythonsupport.categories
%{_kf6_libdir}/libkdevpythoncompletion.so
%{_kf6_libdir}/libkdevpythonduchain.so
%{_kf6_libdir}/libkdevpythonparser.so
%{_kf6_plugindir}/kdevplatform/
%dir %{_kf6_sharedir}/kdevappwizard
%dir %{_kf6_sharedir}/kdevappwizard/templates
%{_kf6_sharedir}/kdevappwizard/templates/django_project.tar.bz2
%{_kf6_sharedir}/kdevappwizard/templates/qtdesigner_app.tar.bz2
%{_kf6_sharedir}/kdevappwizard/templates/simple_pythonapp.tar.bz2
%{_kf6_sharedir}/kdevpythonsupport/

%files lang -f %{name}.lang

%changelog
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- No code change since 25.04.0
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * Fix build with Python 3.13
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Fix build with Python 3.13
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * fix build on musl libc linuxes (header sys/types.h missing in asttransformer.cpp)
  * cls is not only for __new__ methods a valid first argument.
  * Fix a crash in CodeHelpers::expressionUnderCursor()
  * kdevpdb: reduce clazy warnings in DebugSession implementation
  * Fix unused QString
  * Fix c++11 range-loop might detach Qt container
  * Fix Don't use temporary for QRegularexpression
  * Fix Wclazy-qmap-with-pointer-key
  * Lock the DUChain when retrieving the declaration for a StructureType (kde#444055)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Tue Aug 27 2024 Christophe Marin <christophe@krop.fr>
- Add version to 'Requires' and 'Obsoletes'
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Too many changes to list here.
* Fri Jul 19 2024 Christophe Marin <christophe@krop.fr>
- Rename kdevelop5-plugin-python3 to kdevelop-plugin-python3
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Use FindPython3 instead of FindPythonInterp and FindPythonLibs
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Add explicit moc includes to sources for moc-covered headers
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Fri Jun 23 2023 Christophe Marin <christophe@krop.fr>
- Use the latest python version on Tumbleweed
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Thu Mar 16 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch that fixes build with python < 3.9 as in SLE/Backports:
  * fix-for-python3.6.patch
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Mon Jun 20 2022 Ben Greiner <code@bnavigator.de>
- Build for Python 3.9 instead of Python3.10
  * https://invent.kde.org/kdevelop/kdev-python/-/issues/4
  * bpo#40939
  * rh#1898116
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Add CI
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
* Wed Feb  3 2021 wbauer@tmo.at
- Update to 5.6.2
  * No code changes
* Wed Dec  9 2020 wbauer@tmo.at
- Update to 5.6.1
  * Fix an incompatibility with Python versions earlier than 3.9.0,
    which led to instability (kde#426292)
  * Change PEP8 max line length configuration single steps to 1
* Tue Sep  8 2020 wbauer@tmo.at
- Update to 5.6.0
  * Support for Python 3.9 (kde#419290)
    + Distro packages may be compiled against an earlier CPython
    version, and thus not include this
  * Set parser feature version correctly for Python 3.8+
  * Fix highlighting range bugs with CPython 3.8.2+
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Tue Jun  2 2020 wbauer@tmo.at
- Update to 5.5.2
  * No code changes
* Tue May  5 2020 wbauer@tmo.at
- Update to 5.5.1
  * No code changes
* Mon Feb  3 2020 wbauer@tmo.at
- Update to 5.5.0
  * Initial Python 3.8 support (kde#411956)
* Tue Jan  7 2020 wbauer@tmo.at
- Update to 5.4.6
  * No code changes
* Mon Dec  2 2019 wbauer@tmo.at
- Update to 5.4.5
  * No code changes
* Tue Nov  5 2019 wbauer@tmo.at
- Update to 5.4.4
  * No code changes
* Tue Oct 22 2019 wbauer@tmo.at
- Update to 5.4.3
  * No code changes
* Tue Sep  3 2019 wbauer@tmo.at
- Update to 5.4.2
  * no code changes
* Tue Aug 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.4.1
  * no code changes
* Tue Aug  6 2019 wbauer@tmo.at
- New upstream release 5.4.0
  * no code changes, just minor cleanups and adaptions to changes
    in the kdevplatform API
* Thu Jul 18 2019 wbauer@tmo.at
- New upstream release 5.3.3
  * Use KDE_INSTALL_LOGGINGCATEGORIESDIR for kdebugsettings
    .categories file
* Thu Mar  7 2019 wbauer@tmo.at
- New upstream release 5.3.2
  * Fix crash when finding context inside annotated assignments
    (kde#403045)
* Sat Dec 22 2018 wbauer@tmo.at
- New upstream release 5.3.1
  * Remove two outdated methods from shipped built-in documentation
- Run spec-cleaner
* Wed Nov 14 2018 wbauer@tmo.at
- New upstream release 5.3.0
  * Inject environment profile variables into debug process
    environment (kde#322477)
  * Improve support for 'with' statements (kde#399533, kde#399534)
- Remove unnecessary build requirements
* Tue Aug 21 2018 wbauer@tmo.at
- New upstream release 5.2.4
  * no code changes
* Fri May 25 2018 wbauer@tmo.at
- New upstream release 5.2.3 (5.2.2 has been skipped)
  * Ensure that codestyle.py always returns something on stdout to
    unlock m_mutex (kde#392031)
  * Fix crash with contexts opened in the baseclass list of a class
    definition (kde#389326)
  * Fix appstream metadata filename and some content, and install
    it
- New upstream release 5.2.1
  * no code changes
- New upstream release 5.2.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-520-released
  * Fixed a false-positive warning when a name used in a closure
    was defined later in the file
  * Fixed highlighting of local variables in comprehensions and of
    parameters in lambda definitions
  * Infer the correct type when slicing a tuple with constant
    integers
  * Infer the correct type from 'and' or 'or' expressions
  * Internal code cleanups
- Remove superfluous python-qt5 requirement
- Install license file
* Tue Aug 29 2017 wbauer@tmo.at
- New upstream release 5.1.2
  * no code changes
* Sat May 27 2017 wbauer@tmo.at
- New upstream release 5.1.1
  * Fix crash (kde#378827)
  * Pep8: Make pep8 warnings less annoying
* Thu Mar 23 2017 wbauer@tmo.at
- New upstream release 5.1.0
  * For a list of changes, see:
    https://www.kdevelop.org/news/kdevelop-510-released
- Drop build-with-py36.diff, included upstream
- Adjust minimum python3 version, 3.4.3 and higher is supported now
* Sun Mar  5 2017 wbauer@tmo.at
- New upstream release 5.0.4
  * Update version number to 5.0.4
  * Fix crash when requesting raise items without the docfile being
    parsed (kde#373349)
- Rebase build-with-py36.diff
* Wed Feb 22 2017 lbeltrame@kde.org
- Add build-with-py36.diff: diff from upstream 50-python36 branch
  to enable building with Python 3.6
* Fri Dec  2 2016 wbauer@tmo.at
- New upstream release 5.0.3
  * Fix some small issues in the standard library info
* Wed Nov 16 2016 wbauer@tmo.at
- New upstream release 5.0.2
  * no code changes
* Tue Oct  4 2016 lbeltrame@kde.org
- Add QtConcurrent to BuildRequires
* Mon Oct  3 2016 lbeltrame@kde.org
- New upstream release 5.0.1
  * Fix imports sometimes not being found in kdev-python without
    pressing F5 by hand
* Fri Sep 23 2016 lbeltrame@kde.org
- Add conflicts with lang packages, to workaround a
  submission bot bug
* Wed Aug 24 2016 lbeltrame@kde.org
- Add Obsoletes/Provides for old kdevelop packages
* Wed Aug 24 2016 cgiboudeaux@gmx.com
- Update to 5.0.0
* Sat Mar 19 2016 fvogt@suse.com
- Fix build by removing wrong %%file entry
* Thu Jan 28 2016 tittiatcoke@gmail.com
- Initial package for Python3 plugin for KDevelop based on Frameworks
  * KDevelop 5 Beta 3
